@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2021 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2023 The YODA collaboration (see AUTHORS for details)
 //
 #ifndef YODA_Histo1D_h
 #define YODA_Histo1D_h
@@ -417,6 +417,10 @@ namespace YODA {
     /// @}
 
 
+    /// Import to avoid warnings about overload-hiding
+    using AnalysisObject::operator =;
+
+
   protected:
 
     /// Access a bin by coordinate (non-const version)
