@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2021 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2023 The YODA collaboration (see AUTHORS for details)
 //
 #ifndef YODA_ROOTCnv_h
 #define YODA_ROOTCnv_h
@@ -71,7 +71,7 @@ namespace YODA {
   /// Convert a ROOT 1D histogram (excluding TProfile) to a YODA Scatter2D
   ///
   /// The optional bool arg specifies whether or not to divide y vals/errs by bin width.
-  inline Scatter2D toScatter2D(const TH1& th1, bool scalebywidth=false) {
+  inline Scatter2D toScatter2D(const TH1& th1, const bool scalebywidth=false) {
     Scatter2D rtn;
     for (int ix = 1; ix <= th1.GetNbinsX(); ++ix) {
       const TAxis& axx = *th1.GetXaxis();
@@ -96,18 +96,18 @@ namespace YODA {
 
 
   /// Convert a ROOT 1D histogram (excluding TProfile) to a YODA Scatter2D
-  inline Scatter2D toScatter2D(const TH1* th1, bool scalebywidth=false) {
+  inline Scatter2D toScatter2D(const TH1* th1, const bool scalebywidth=false) {
     if (th1 == NULL) throw UserError("Null TH1 pointer passed as argument");
     return toScatter2D(*th1, scalebywidth);
   }
 
 
   /// Convert a ROOT 1D histogram (excluding TProfile) to a new'd YODA Scatter2D
-  inline Scatter2D* toNewScatter2D(const TH1& th1, bool scalebywidth=false) {
+  inline Scatter2D* toNewScatter2D(const TH1& th1, const bool scalebywidth=false) {
     return toScatter2D(th1, scalebywidth).newclone();
   }
   /// Convert a ROOT 1D histogram (excluding TProfile) to a new'd YODA Scatter2D
-  inline Scatter2D* toNewScatter2D(const TH1* th1, bool scalebywidth=false) {
+  inline Scatter2D* toNewScatter2D(const TH1* th1, const bool scalebywidth=false) {
     return toScatter2D(th1, scalebywidth).newclone();
   }
 
@@ -143,7 +143,7 @@ namespace YODA {
   /// Convert a ROOT 2D histogram to a YODA Scatter3D
   ///
   /// The optional bool arg specifies whether or not to divide y vals/errs by bin area.
-  inline Scatter3D toScatter3D(const TH2& th2, bool scalebyarea=false) {
+  inline Scatter3D toScatter3D(const TH2& th2, const bool scalebyarea=false) {
     Scatter3D rtn;
     for (int ix = 1; ix <= th2.GetNbinsX(); ++ix) {
       for (int iy = 1; iy <= th2.GetNbinsY(); ++iy) {
@@ -180,18 +180,18 @@ namespace YODA {
 
 
   /// Convert a ROOT 2D histogram to a YODA Scatter3D
-  inline Scatter3D toScatter3D(const TH2* th2, bool scalebyarea=false) {
+  inline Scatter3D toScatter3D(const TH2* th2, const bool scalebyarea=false) {
     if (th2 == NULL) throw UserError("Null TH2 pointer passed as argument");
     return toScatter3D(*th2, scalebyarea);
   }
 
 
   /// Convert a ROOT 2D histogram to a new'd YODA Scatter3D
-  inline Scatter3D* toNewScatter3D(const TH2& th2, bool scalebyarea=false) {
+  inline Scatter3D* toNewScatter3D(const TH2& th2, const bool scalebyarea=false) {
     return toScatter3D(th2, scalebyarea).newclone();
   }
   /// Convert a ROOT 2D histogram to a new'd YODA Scatter3D
-  inline Scatter3D* toNewScatter3D(const TH2* th2, bool scalebyarea=false) {
+  inline Scatter3D* toNewScatter3D(const TH2* th2, const bool scalebyarea=false) {
     return toScatter3D(th2, scalebyarea).newclone();
   }
 
@@ -216,7 +216,7 @@ namespace YODA {
   /// @brief Convert a YODA Histo1D to a ROOT 1D histogram
   ///
   /// @todo Check/improve/extend -- needs SetBinError or not?
-  inline TH1D toTH1D(const Histo1D& h, bool scalebywidth=false) {
+  inline TH1D toTH1D(const Histo1D& h, const bool scalebywidth=false) {
     // Work out bin edges first
     std::vector<double> edges;
     edges.reserve(h.numBins()+1);
@@ -249,7 +249,7 @@ namespace YODA {
   }
 
   /// @brief Convert a YODA Histo1D to a ROOT 1D histogram as new'd pointer
-  inline TH1D* toNewTH1D(const Histo1D& h, const std::string& rootname, bool scalebywidth=false) {
+  inline TH1D* toNewTH1D(const Histo1D& h, const std::string& rootname, const bool scalebywidth=false) {
     return (TH1D*) toTH1D(h, scalebywidth).Clone(rootname.c_str());
   }
 
@@ -258,7 +258,7 @@ namespace YODA {
   /// @brief Convert a YODA Histo2D to a ROOT 2D histogram
   ///
   /// @todo Check/improve/extend -- needs SetBinError or not?
-  inline TH2D toTH2D(const Histo2D& h, bool scalebyarea=false) {
+  inline TH2D toTH2D(const Histo2D& h, const bool scalebyarea=false) {
     // Work out bin edges first
     std::vector<double> xedges, yedges;
     xedges.reserve(h.numBins()+1);
@@ -309,7 +309,7 @@ namespace YODA {
   }
 
   /// @brief Convert a YODA Histo2D to a ROOT 2D histogram as new'd pointer
-  inline TH2D* toNewTH2D(const Histo2D& h, const std::string& rootname, bool scalebyarea=false) {
+  inline TH2D* toNewTH2D(const Histo2D& h, const std::string& rootname, const bool scalebyarea=false) {
     return (TH2D*) toTH2D(h, scalebyarea).Clone(rootname.c_str());
   }
 
@@ -446,13 +446,13 @@ namespace YODA {
 
   /// @brief Convert a YODA Histo1D to a ROOT TGraphAsymmErrors
   inline TGraphAsymmErrors toTGraph(const Histo1D& h,
-                                    bool usefocus=false, bool widthscale=false) {
+                                    const bool usefocus=false, const bool widthscale=false) {
     return toTGraph(mkScatter(h, usefocus, widthscale));
   }
 
   /// @brief Convert a YODA Histo1D to a ROOT TGraphAsymmErrors as new'd pointer
   inline TGraphAsymmErrors* toNewTGraph(const Histo1D& h, const std::string& rootname,
-                                        bool usefocus=false, bool widthscale=false) {
+                                        const bool usefocus=false, const bool widthscale=false) {
     return (TGraphAsymmErrors*) toTGraph(h, usefocus, widthscale).Clone(rootname.c_str());
   }
 
@@ -465,7 +465,7 @@ namespace YODA {
 
   /// @brief Convert a YODA Profile1D to a ROOT TGraphAsymmErrors as new'd pointer
   inline TGraphAsymmErrors* toNewTGraph(const Profile1D& p, const std::string& rootname,
-                                        bool usefocus=false) {
+                                        const bool usefocus=false) {
     return (TGraphAsymmErrors*) toTGraph(p, usefocus).Clone(rootname.c_str());
   }
 
