@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2021 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2023 The YODA collaboration (see AUTHORS for details)
 //
 #include "YODA/Histo1D.h"
 #include "YODA/Profile1D.h"
@@ -179,7 +179,7 @@ namespace YODA {
         /// @todo Is this the exact error treatment for all (uncorrelated) cases? Behaviour around 0? +1 and -1 fills?
         const double relerr_1 = b1.heightErr() != 0 ? b1.relErr() : 0;
         const double relerr_2 = b2.heightErr() != 0 ? b2.relErr() : 0;
-        ey = y * sqrt(sqr(relerr_1) + sqr(relerr_2));
+        ey = fabs(y) * sqrt(sqr(relerr_1) + sqr(relerr_2));
       }
 
       /// Deal with +/- errors separately, inverted for the denominator contributions:
@@ -404,8 +404,7 @@ namespace YODA {
       if (!fuzzyEquals(b.xMin(), s.x() - s.xErrMinus()) || !fuzzyEquals(b.xMax(), s.x() + s.xErrPlus()))
         throw BinningError("x binnings are not equivalent in " + numer.path() + " / " + denom.path());
 
-
-      // convert bin to scatter point
+      // Convert bin to scatter point
       double biny;
       try {
         biny = b.height();
@@ -418,7 +417,7 @@ namespace YODA {
       } catch (const Exception&) { // LowStatsError or WeightError
         biney = 0;
       }
-      // combine with scatter values
+      // Combine with scatter values
       double newy, newey_p, newey_m;
       if (s.y() == 0 || (b.height() == 0 && b.heightErr() != 0)) { ///< @todo Ok?
         newy = std::numeric_limits<double>::quiet_NaN();
@@ -426,10 +425,10 @@ namespace YODA {
         // throw LowStatsError("Requested division of empty bin");
       } else {
         newy = biny / s.y();
-        newey_p = newy * sqrt(sqr(biney) + sqr(s.yErrPlus()  / s.y()));
-        newey_m = newy * sqrt(sqr(biney) + sqr(s.yErrMinus() / s.y()));
+        newey_p = fabs(newy) * sqrt(sqr(biney) + sqr(s.yErrPlus()  / s.y()));
+        newey_m = fabs(newy) * sqrt(sqr(biney) + sqr(s.yErrMinus() / s.y()));
       }
-      // set new values
+      // Set new values
       Point2D& t = rtn.point(i);
       t.setY(newy);
       t.setYErrMinus(newey_p);
