@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2021 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2023 The YODA collaboration (see AUTHORS for details)
 //
 #include "YODA/ReaderYODA.h"
 #include "YODA/Reader.h"
@@ -34,6 +34,11 @@
 #include <locale>
 #include <string>
 #include <cstring>
+
+#ifdef WITH_OSX
+#include <xlocale.h>
+#endif
+
 using namespace std;
 
 namespace YODA {
