@@ -28,7 +28,9 @@ int main() {
   vector< shared_ptr<AnalysisObject> > aos;
   aos.push_back( static_pointer_cast<AnalysisObject>(h) );
   WriterYODA::write("testwriter2.yoda", aos);
+  #ifdef HAVE_LIBZ
   WriterYODA::write("testwriter2.yoda.gz", aos);
+  #endif
 
   return EXIT_SUCCESS;
 }
