@@ -27,15 +27,22 @@ for aos in [
         yoda.read(StringIO(open(ypath, "r").read())),
         yoda.readYODA(ypath),
         yoda.readYODA(open(ypath, "r")),
-        yoda.readYODA(StringIO(open(ypath, "r").read())),
+        yoda.readYODA(StringIO(open(ypath, "r").read()))]:
+    print(aos.keys())
+    assert set(aos.keys()) == set(aos_ref.keys())
 
-        # Compressed
+# Compressed
+# TODO: programmatically detect if gz-enabled
+try:
+    for aos in [
         yoda.read(yzpath),
         yoda.read(open(yzpath, "rb")),
         yoda.read(BytesIO(open(yzpath, "rb").read())),
         yoda.readYODA(yzpath),
         yoda.readYODA(open(yzpath, "rb")),
-        yoda.readYODA(BytesIO(open(yzpath, "rb").read())),
-]:
-    print(aos.keys())
-    assert set(aos.keys()) == set(aos_ref.keys())
+        yoda.readYODA(BytesIO(open(yzpath, "rb").read()))]:
+        print(aos.keys())
+        assert set(aos.keys()) == set(aos_ref.keys())
+except Exception as e:
+    if "compiled without zlib" not in str(e):
+        raise e
