@@ -31,6 +31,10 @@ for _, ao in aos.items():
     print("variations = " + repr(ao.variations()))
     print("hasValidErrorBreakdown = " + repr(ao.hasValidErrorBreakdown()))
     print("covarianceMatrix = " + repr(ao.covarianceMatrix()))
+    assert(abs(ao.covarianceMatrix()[0][0]-0.2125)<0.0001)
+    assert(abs(ao.covarianceMatrix(ignoreOffDiagonalTerms=True)[0][0]-0.2125)<0.0001)
+    assert(ao.covarianceMatrix(ignoreOffDiagonalTerms=True)[1][0]==0.0)
+    print("diagonal covarianceMatrix = " + repr(ao.covarianceMatrix(ignoreOffDiagonalTerms=True)))
     print("correlationMatrix = " + repr(ao.correlationMatrix()))
     assert(ao.variations() == s.variations()) 
     assert(ao.point(0).errMap() == s.point(0).errMap()) 
